% This source code is (c) Copyright 2008 by Lei Li.
% All rights preserved.
%
% Permission is granted to use it for non-profit purposes,
% including research and teaching. For-profit use requires
% the express consent of the author.

function [eng, stigap, scores] = adaptiveGapStitch(x, y, t, MAX)
%adaptively choose the intermediate stitching points and select the one
%with the minimum energy(laziness)
% x: the first motion (taking off at the end of x)
% y: the second motion (landing at the beginning)
% t: the interval time gap (e.g. 1)
% MAX: the maximum of gaps allowed during stitching (default 20)

if (nargin < 4) 
    MAX = 20;
end

scores = zeros(MAX, 1);
for i = 1 : MAX
    [pos, speed, acc] = estimateStitching(x, y, t, i);
    eng = computeWindowedEnergy(pos, speed, acc, t);
    scores(i) = eng;
end
[eng, stigap] = min(scores);
