% This source code is (c) Copyright 2008 by Lei Li.
% All rights preserved.
%
% Permission is granted to use it for non-profit purposes,
% including research and teaching. For-profit use requires
% the express consent of the author.

function [position velocity acceleration] = estimateState(x, t, obs)
%x is N * M dimension, N is the total frame number, M is the feature number (e.g. 300 * 90)
%estimate the position, velocity, and acceleration
%obs: indicating whether x(i) is observed or missing

if (nargin < 2)
    t = 1;
end

if (nargin < 3) 
    obs = ones(size(x, 1), 1);
end


A = [1 1*t 0.5*t*t; 0 1 1*t; 0 0 1];
% try different parameters here
% 0.1 0.01 0.001 etc. 
Gamma = 0.000001 * eye(3);
C = [1 0 0];
Sigma = 0.000001;
u0 = [0 0 0]';
V0 = eye(3) * 0.0001;

N = size(x, 1);
M = size(x, 2);
position = zeros(N, M);
velocity = zeros(N, M);
acceleration = zeros(N, M);
for i=1:M
    %initializing 
    u0(1) = x(1, i);
    u0(2) = (x(2, i) - x(1,i)) / t;
    u0(3) = (x(3, i) + x(1, i) - 2 * x(2, i))/t/t;
    [z] = estimatePosterior(x(:, i), A, Gamma, C, Sigma, u0, V0, obs);
    temp = cell2mat(z');
    position(:, i) = temp(1, :);
    velocity(:, i) = temp(2, :);
    acceleration(:, i) = temp(3, :);
end
